pitchtools.calculate_melodic_chromatic_interval
===============================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_chromatic_interval.calculate_melodic_chromatic_interval
   :noindex:
